About
-----

The aim of this module is to provide an easy way to compute dendrograms of observed or simulated Astronomical data in Python

Documentation
-------------

For information on installing and using ``astrodendro``, please visit [https://dendrograms.readthedocs.io/](https://dendrograms.readthedocs.io/)

Reporting issues
----------------

Please report issues via the [GitHub issue tracker](https://github.com/dendrograms/astrodendro/issues)

Credits
-------

This package was developed by:

* [Braden MacDonald](https://github.com/bradenmacdonald)
* [Chris Beaumont](https://github.com/ChrisBeaumont)
* [Thomas Robitaille](https://github.com/astrofrog)
* [Adam Ginsburg](https://github.com/keflavich)
* [Erik Rosolowsky](https://github.com/low-sky)

Build and coverage status
-------------------------

[![Build Status](https://travis-ci.org/dendrograms/astrodendro.svg?branch=master)](https://travis-ci.org/dendrograms/astrodendro)
[![Coverage Status](https://coveralls.io/repos/dendrograms/astrodendro/badge.svg?branch=master)](https://coveralls.io/r/dendrograms/astrodendro?branch=master)
